@@ -10,17 +10,18 @@ describe 'swift::proxy' do
       let :pre_condition do
         "class { memcached: max_memory => 1}
          class { swift: swift_hash_path_suffix => string }
+         include swift::proxy::catch_errors
+         include swift::proxy::gatekeeper
          include swift::proxy::healthcheck
+         include swift::proxy::proxy_logging
          include swift::proxy::cache
-         include swift::proxy::tempauth"
+         include swift::proxy::listing_formats
+         include swift::proxy::tempauth
+         include swift::proxy::copy"
       end
 
       describe 'without the proxy local network ip address being specified' do
-        if Puppet::Util::Package.versioncmp(Puppet.version, '4.3.0') >= 0
-          it_raises 'a Puppet::Error', /expects a value for parameter 'proxy_local_net_ip'/
-        else
-          it_raises 'a Puppet::Error', /Must pass proxy_local_net_ip/
-        end
+        it_raises 'a Puppet::Error', /expects a value for parameter 'proxy_local_net_ip'/
       end
 
       describe 'when proxy_local_net_ip is set' do
@@ -56,24 +57,37 @@ describe 'swift::proxy' do
         it { should contain_swift_proxy_config('DEFAULT/log_level').with_value('INFO') }
         it { should contain_swift_proxy_config('DEFAULT/log_headers').with_value('False') }
         it { should contain_swift_proxy_config('DEFAULT/log_address').with_value('/dev/log') }
-        it { should contain_swift_proxy_config('pipeline:main/pipeline').with_value('healthcheck cache tempauth proxy-server') }
+        it { should contain_swift_proxy_config('DEFAULT/client_timeout').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('pipeline:main/pipeline').with_value(
+          ['catch_errors', 'gatekeeper', 'healthcheck', 'proxy-logging', 'cache',
+           'listing_formats', 'tempauth', 'copy', 'proxy-logging', 'proxy-server'].join(' ')) }
         it { should contain_swift_proxy_config('app:proxy-server/use').with_value('egg:swift#proxy') }
         it { should contain_swift_proxy_config('app:proxy-server/set log_name').with_value('proxy-server') }
         it { should contain_swift_proxy_config('app:proxy-server/set log_facility').with_value('LOG_LOCAL2') }
         it { should contain_swift_proxy_config('app:proxy-server/set log_level').with_value('INFO') }
         it { should contain_swift_proxy_config('app:proxy-server/set log_address').with_value('/dev/log') }
-        it { should contain_swift_proxy_config('app:proxy-server/log_handoffs').with_value('true') }
-        it { should contain_swift_proxy_config('app:proxy-server/object_chunk_size').with_value('65536') }
-        it { should contain_swift_proxy_config('app:proxy-server/client_chunk_size').with_value('65536') }
+        it { should contain_swift_proxy_config('app:proxy-server/log_handoffs').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/object_chunk_size').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/client_chunk_size').with_value('<SERVICE DEFAULT>') }
         it { should contain_swift_proxy_config('app:proxy-server/allow_account_management').with_value('true') }
         it { should contain_swift_proxy_config('app:proxy-server/account_autocreate').with_value('true') }
-        it { should contain_swift_proxy_config('app:proxy-server/max_containers_per_account').with_value(0) }
+        it { should contain_swift_proxy_config('app:proxy-server/max_containers_per_account').with_value('<SERVICE DEFAULT>') }
         it { should contain_swift_proxy_config('app:proxy-server/max_containers_whitelist').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/write_affinity').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/write_affinity_node_count').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/node_timeout').with_value('<SERVICE DEFAULT>') }
+        it { should contain_swift_proxy_config('app:proxy-server/recoverable_node_timeout').with_value('<SERVICE DEFAULT>') }
 
         it { should contain_service('swift-proxy-server').with_require([
+          'Class[Swift::Proxy::Catch_errors]',
+          'Class[Swift::Proxy::Gatekeeper]',
           'Class[Swift::Proxy::Healthcheck]',
+          'Class[Swift::Proxy::Proxy_logging]',
           'Class[Swift::Proxy::Cache]',
+          'Class[Swift::Proxy::Listing_formats]',
           'Class[Swift::Proxy::Tempauth]',
+          'Class[Swift::Proxy::Copy]',
+          'Class[Swift::Proxy::Proxy_logging]',
         ])}
 
         describe "when using swift_proxy_config resource" do
@@ -82,9 +96,14 @@ describe 'swift::proxy' do
               class { memcached: max_memory => 1}
               class { swift: swift_hash_path_suffix => string }
               swift_proxy_config { 'foo/bar': value => 'foo' }
+              include swift::proxy::catch_errors
+              include swift::proxy::gatekeeper
               include swift::proxy::healthcheck
+              include swift::proxy::proxy_logging
               include swift::proxy::cache
+              include swift::proxy::listing_formats
               include swift::proxy::tempauth
+              include swift::proxy::copy
             "
           end
 
@@ -140,7 +159,7 @@ describe 'swift::proxy' do
           it { should contain_swift_proxy_config('app:proxy-server/set log_facility').with_value('LOG_LOCAL2') }
           it { should contain_swift_proxy_config('app:proxy-server/set log_level').with_value('DEBUG') }
           it { should contain_swift_proxy_config('app:proxy-server/set log_address').with_value('/dev/log') }
-          it { should contain_swift_proxy_config('app:proxy-server/log_handoffs').with_value('true') }
+          it { should contain_swift_proxy_config('app:proxy-server/log_handoffs').with_value('<SERVICE DEFAULT>') }
           it { should contain_swift_proxy_config('app:proxy-server/object_chunk_size').with_value('8192') }
           it { should contain_swift_proxy_config('app:proxy-server/client_chunk_size').with_value('8192') }
           it { should contain_swift_proxy_config('app:proxy-server/allow_account_management').with_value('false') }
@@ -193,6 +212,7 @@ describe 'swift::proxy' do
                 :log_name                  => 'swift-proxy-server',
                 :log_udp_host              => '127.0.0.1',
                 :log_udp_port              => '514',
+                :log_handoffs              => true,
                 :read_affinity             => 'r1z1=100, r1=200',
                 :write_affinity            => 'r1',
                 :write_affinity_node_count => '2 * replicas',
@@ -273,12 +293,16 @@ describe 'swift::proxy' do
     let :pre_condition do
       "class { memcached: max_memory => 1}
        class { swift: swift_hash_path_suffix => string }
+       include swift::proxy::catch_errors
+       include swift::proxy::gatekeeper
        include swift::proxy::healthcheck
+       include swift::proxy::proxy_logging
        include swift::proxy::cache
-       include swift::proxy::tempauth"
+       include swift::proxy::listing_formats
+       include swift::proxy::tempauth
+       include swift::proxy::copy"
     end
 
-
     [{ :enabled => true, :manage_service => true },
      { :enabled => false, :manage_service => true }].each do |param_hash|
       context "when service should be #{param_hash[:enabled] ? 'enabled' : 'disabled'}" do
@@ -298,23 +322,15 @@ describe 'swift::proxy' do
       end
     end
 
-    context 'with disabled service managing and service provider' do
+    context 'with disabled service management' do
       before do
         params.merge!({
-          :manage_service   => false,
-          :enabled          => false,
-          :service_provider => 'swiftinit',
+          :manage_service => false,
         })
       end
 
-      it 'configures swift-proxy-server service' do
-        should contain_service('swift-proxy-server').with(
-          :ensure    => nil,
-          :name      => 'swift-proxy-server',
-          :provider  => 'swiftinit',
-          :enable    => false,
-          :hasstatus => true,
-        )
+      it 'does not configure swift-proxy-server service' do
+        should_not contain_service('swift-proxy-server')
       end
     end
   end
@@ -328,7 +344,7 @@ describe 'swift::proxy' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { 'swift-proxy-server' => 'swift-proxy' }
         when 'RedHat'
